@@ -1,5 +1,7 @@
 """
-Main interface for kinesisanalytics service literal definitions.
+Type annotations for kinesisanalytics service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/literals.html)
 
 Usage::
 
